@@ -62,12 +62,7 @@ class IterableApi():
 		r = requests.request(method=method, url=self.base_uri+call, params=params,
 							 headers=headers, data=data, json=json)
 
-		if (r.status_code == 200):
-			
-			return r.json()
-
-		else:
-			return r.status_code
+		return r.json()
 
 	"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
 
@@ -86,7 +81,7 @@ class IterableApi():
 						send_mode=None, start_time_zone=None,
 						default_time_zone=None, data_fields=None):
 
-		call = "/api/capaigns/create"
+		call = "/api/campaigns/create"
 
 		payload ={}
 
@@ -98,7 +93,7 @@ class IterableApi():
 		else:
 			raise TypeError('ListIds are not in the required Array format')
 
-		payload["template_id"]= template_id
+		payload["templateId"]= template_id
 
 		if suppression_list_ids is not None:
 			payload["supressionListIds"]= suppression_list_ids
@@ -116,7 +111,7 @@ class IterableApi():
 			payload["defaultTimeZone"]= str(default_time_zone)
 
 		if data_fields is not None:
-			payload["dataField"]= data_fields
+			payload["dataFields"]= data_fields
 
 		return self.api_call(call=call, method="POST", json=payload)
 
